==> nextcloud-app-spreed-1%3A7.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/mk.js <==
OC.L10N.register(
    "spreed",
    {
    "Enter name for a new conversation" : "Внеси име за нов разговор",
    "{name} (public)" : "{name} (јавно)",
    "New conversation …" : "Нов разговор ...",
    "Participants" : "Учесници",
    "Projects" : "Проекти",
    "Chat" : "Разговор",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
    "Start a conversation" : "Започни разговор",
    "Share" : "Сподели",
    "Room name can not be empty" : "Името на собата неможе да биде празно",
    "Request password" : "Барање на лозинка",
    "Error requesting the password." : "Грешка при барање на лозинка",
    "Please enter the password for this call" : "Внесете лозинка за да пристапите кон овој разговор",
    "Password required" : "Потребна е лозинка",
    "Password" : "Лозинка",
    "Cancel" : "Откажи",
    "Submit" : "Испрати",
    "Leave call" : "Напушти го повикот",
    "Join call" : "Приклучи се кон повикот",
    "Start call" : "Повик",
    "Calls are disabled in this conversation." : "Повиците се оневозможени во овој разговор.",
    "Go to file" : "Оди до датотеката",
    "Share link" : "Сподели линк",
    "Copy link" : "Копирај линк",
    "Enable for" : "Овозможено за",
    "All participants" : "Сите учесници",
    "Moderators only" : "Само модераторите",
    "Start time (optional)" : "Време на почеток (опционално)",
    "Change password" : "Промени лозинка",
    "Set password" : "Постави лозинка",
    "Error occurred while renaming the room" : "Настана грешка при обидот за преименување на собата",
    "Name" : "Име",
    "Conversation name" : "Име на разговорот",
    "Rename" : "Преименувај",
    "Link copied!" : "Линкот е копиран!",
    "Conversation with {name}" : "Разговор со {name}",
    "Error occurred while making the room public" : "Настана грешка при обидот за промена на собата во јавна",
    "Error occurred while making the room private" : "Настана грешка при обидот за промена на собата во приватна",
    "Error occurred while setting password" : "Настана грешка при обидот за поставување на лозинка",
    "Error occurred while enabling for all participants" : "Настана грешка при обидот за овозможување на сите учесници",
    "Error occurred while enabling only for moderators" : "Настана грешка при обидот за овозможување само на модераторите",
    "Invalid start time format" : "Погрењен формат за време на почеток",
    "You" : "Ти",
    "Guest" : "Гостин",
    "No messages yet, start the conversation!" : "Сеуште нема пораки, започнете разговор!",
    "New message …" : "Нова порака ...",
    "Send" : "Испрати",
    "You can not send messages, because the conversation is locked." : "Неможете да испратите порака, бидејќи разговорот е заклучен.",
    "The conversation is locked." : "Разговорот е заклучен.",
    "[Unknown user name]" : "[Непознато корисничко име]",
    "Today" : "Денес",
    "Yesterday" : "Вчера",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Пораката која се обидувате да ја испратите е премногу долга",
    "Error occurred while sending message" : "Настана грешка при обидот за испраќање на порака",
    "File to share" : "Датотека за споделување",
    "Error while sharing" : "Грешка при споделување",
    "Edit" : "Уреди",
    "Join a conversation or start a new one" : "Приклучи се кон разговорот или започни нов",
    "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
    "Mute audio" : "Занеми (Mute) аудио",
    "Disable video" : "Оневозможи видео",
    "Share screen" : "Сподели екран",
    "Add to favorites" : "Додади во фаворити",
    "Close" : "Затвори",
    "(Duration %s)" : "(Времетраење %s)",
    "_%n guest_::_%n guests_" : ["1 гостин","%n гости"],
    "_%n other_::_%n others_" : ["уште 1","%n други"],
    "%s (guest)" : "%s (гостин)",
    "Delete server" : "Избриши сервер",
    "Add new server" : "Додади нов сервер",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Ги избришавте сите STUN сервери. Бидејќи најчесто е потребен, додаден е стандарден STUN сервер.",
    "TURN server shared secret" : "Лозинка на TURN серверот",
    "Test server" : "Тестирај сервер",
    "New public conversation" : "Нов јавен разговор",
    "New group conversation" : "Нов групен разговор",
    "Always notify" : "Секогаш известувај",
    "Notify on @-mention" : "Известувај на @-спомнување",
    "Never notify" : "Не известувај",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Поканети сте во група за <strong>разговор</strong> или имате <strong>повик</strong>",
    "_%n other guest_::_%n other guests_" : ["1 гостин","%n други гости"],
    ", " : ", ",
    "Join now" : "Приклучи се",
    "{user} sent a message in a conversation" : "{user} испрати порака во разговор",
    "A deleted user sent a message in a conversation" : "Избришан корисник испрати порака во разговор",
    "A guest sent a message in a conversation" : "Гостин испрати порака во разговор",
    "{user} mentioned you in a conversation" : "{user} те спомна во разговор",
    "A deleted user mentioned you in a conversation" : "Избришан корисник те спомна во разговор",
    "A guest mentioned you in a conversation" : "Гостин те спомна во разговор",
    "%s invited you to a private conversation" : "%s те покани на приватен разговор",
    "%s invited you to a group conversation: %s" : "%s те покани на групен разговор: %s",
    "%s invited you to a group conversation" : "%s те покани на групен разговор",
    "{user} invited you to a group conversation" : "{user} те покани на групен разговор",
    "A group call has started" : "Започна групен повик",
    "Someone requested the password to access {file}" : "Испратено барање за лозинка за пристап до {file}",
    "Unnamed conversation" : "Неименуван разговор",
    "Video & audio-conferencing using WebRTC" : "Видео & аудио конференцина со користење на WebRTC",
    "This call is password-protected" : "Разговорот е заштитен со лозинка",
    "Signaling server" : "Сервер за сигнализација"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-spreed-1%3A8.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/mk.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Времетраење %s)",
    "_%n guest_::_%n guests_" : ["1 гостин","%n гости"],
    "_%n other_::_%n others_" : ["уште 1","%n други"],
    "Talk" : "Разговор",
    "Guest" : "Гостин",
    "%s (guest)" : "%s (гостин)",
    "Join call" : "Приклучи се кон повикот",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, форматот мора да биде ГГГГ-ММ-ДД",
    "Request password" : "Барање на лозинка",
    "Error requesting the password." : "Грешка при барање на лозинка",
    "None" : "Ништо",
    "User" : "Корисник",
    "Everyone" : "Секој",
    "Disabled" : "Оневозможен",
    "Users" : "Корисници",
    "Copy link" : "Копирај линк",
    "Disable video" : "Оневозможи видео",
    "Favorite" : "Омилен",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "Contacts" : "Контакти",
    "Groups" : "Групи",
    "Circles" : "Кругови",
    "Loading" : "Се вчитува",
    "Error" : "Грешка",
    "Password protect" : "Заштити со лозинка",
    "Back" : "Назад",
    "Close" : "Затвори",
    "Conversation name" : "Име на разговорот",
    "Reply" : "Одговор",
    "[Unknown user name]" : "[Непознато корисничко име]",
    "Today" : "Денес",
    "Yesterday" : "Вчера",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "File to share" : "Датотека за споделување",
    "Invalid path selected" : "Избрана невалидна патека",
    "guest" : "гостин",
    "No results" : "Нема резултати",
    "Participants" : "Учесници",
    "Searching …" : "Пребарување ...",
    "Guests" : "Гости",
    "Share link" : "Сподели линк",
    "Password protection" : "Заштитено со лозинка",
    "Enter a password" : "Внесете лозинка",
    "Start time (optional)" : "Време на почеток (опционално)",
    "Chat" : "Разговор",
    "Projects" : "Проекти",
    "Edit" : "Уреди",
    "Leave call" : "Напушти го повикот",
    "Start call" : "Повик",
    "Limit to groups" : "Ограничување на групи",
    "Save changes" : "Зачувај ги промените",
    "Saving …" : "Зачувува ...",
    "Saved!" : "Зачувано!",
    "Beta" : "Бета",
    "Name" : "Име",
    "General settings" : "Општи параметри",
    "Moderators only" : "Само модераторите",
    "Saved" : "Зачувано",
    "Join a conversation or start a new one" : "Приклучи се кон разговорот или започни нов",
    "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
    "Please enter the password for this call" : "Внесете лозинка за да пристапите кон овој разговор",
    "Password required" : "Потребна е лозинка",
    "Password" : "Лозинка",
    "Cancel" : "Откажи",
    "Submit" : "Испрати",
    "The password is wrong. Try again." : "Лозинката е погрешна. Обидите се повторно.",
    "%s Talk on your mobile devices" : "%s Разговор на вашиоте мобилни уреди",
    "Android app" : "Android апликација",
    "iOS app" : "iOS апликација",
    "Delete server" : "Избриши сервер",
    "Add new server" : "Додади нов сервер",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Ги избришавте сите STUN сервери. Бидејќи најчесто е потребен, додаден е стандарден STUN сервер.",
    "TURN server shared secret" : "Лозинка на TURN серверот",
    "Test server" : "Тестирај сервер",
    "New public conversation" : "Нов јавен разговор",
    "New group conversation" : "Нов групен разговор",
    "{name} (public)" : "{name} (јавно)",
    "New conversation …" : "Нов разговор ...",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
    "Start a conversation" : "Започни разговор",
    "Share" : "Сподели",
    "Change password" : "Промени лозинка",
    "Set password" : "Постави лозинка",
    "Go to file" : "Оди до датотеката",
    "Rename" : "Преименувај",
    "Conversation with {name}" : "Разговор со {name}",
    "Error occurred while setting password" : "Настана грешка при обидот за поставување на лозинка",
    "Link copied!" : "Линкот е копиран!",
    "You" : "Ти",
    "No messages yet, start the conversation!" : "Сеуште нема пораки, започнете разговор!",
    "New message …" : "Нова порака ...",
    "Send" : "Испрати",
    "The message you are trying to send is too long" : "Пораката која се обидувате да ја испратите е премногу долга",
    "Error occurred while sending message" : "Настана грешка при обидот за испраќање на порака",
    "Error while sharing" : "Грешка при споделување",
    "Mute audio" : "Занеми (Mute) аудио",
    "Share screen" : "Сподели екран",
    "Favorited" : "Омилени",
    "Always notify" : "Секогаш известувај",
    "Notify on @-mention" : "Известувај на @-спомнување",
    "Never notify" : "Не известувај",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Поканети сте во група за <strong>разговор</strong> или имате <strong>повик</strong>",
    "_%n other guest_::_%n other guests_" : ["1 гостин","%n други гости"],
    ", " : ", ",
    "Join now" : "Приклучи се",
    "{user} sent a message in a conversation" : "{user} испрати порака во разговор",
    "A deleted user sent a message in a conversation" : "Избришан корисник испрати порака во разговор",
    "A guest sent a message in a conversation" : "Гостин испрати порака во разговор",
    "{user} mentioned you in a conversation" : "{user} те спомна во разговор",
    "A deleted user mentioned you in a conversation" : "Избришан корисник те спомна во разговор",
    "A guest mentioned you in a conversation" : "Гостин те спомна во разговор",
    "%s invited you to a private conversation" : "%s те покани на приватен разговор",
    "%s invited you to a group conversation: %s" : "%s те покани на групен разговор: %s",
    "%s invited you to a group conversation" : "%s те покани на групен разговор",
    "{user} invited you to a group conversation" : "{user} те покани на групен разговор",
    "A group call has started" : "Започна групен повик",
    "Someone requested the password to access {file}" : "Испратено барање за лозинка за пристап до {file}",
    "Unnamed conversation" : "Неименуван разговор",
    "Video & audio-conferencing using WebRTC" : "Видео & аудио конференцина со користење на WebRTC",
    "This call is password-protected" : "Разговорот е заштитен со лозинка",
    "Signaling server" : "Сервер за сигнализација",
    "Join conversations at any time, any where, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
    "Enter name for a new conversation" : "Внеси име за нов разговор",
    "Room name can not be empty" : "Името на собата неможе да биде празно",
    "Calls are disabled in this conversation." : "Повиците се оневозможени во овој разговор.",
    "Error occurred while renaming the room" : "Настана грешка при обидот за преименување на собата",
    "Error occurred while making the room public" : "Настана грешка при обидот за промена на собата во јавна",
    "Error occurred while making the room private" : "Настана грешка при обидот за промена на собата во приватна",
    "You can not send messages, because the conversation is locked." : "Неможете да испратите порака, бидејќи разговорот е заклучен.",
    "The conversation is locked." : "Разговорот е заклучен.",
    "Invalid start time format" : "Погрењен формат за време на почеток"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
